Potential
=========

.. currentmodule:: cosmax.spectral_ops

.. autoclass:: Potential
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Potential.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
